<?php

namespace App\Http\Controllers\Admin\AdminApplications;

use Carbon\Carbon;
use App\Models\User;
use ReflectionClass;
use App\Models\Announcement;
use App\Models\UserApplication;
use App\Notifications\GeneralInfo;
use App\Models\ProducerApplication;
use Flasher\Prime\FlasherInterface;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Notification;

class AdminApplicationController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:admin']);
    }
    public function index($id)
    {
        $application = ProducerApplication::with('application','user')->find($id);
        return view('admin.admin_applications.application', ['application' => $application]);
    }

    public function accept_application(FlasherInterface $flasher, $id)
    {
        $application = ProducerApplication::with('application')->find($id);
        $application->approved = true;
        $application->update();

        $application->application->approved_at = Carbon::now();
        $application->application->save();

        $builder = $flasher->success("Application accepted successfully");
        $builder->flash();

        $user = User::where('id', '=', $application->user_id)->first();
        $announcement = new Announcement();
        $announcement->title = "Application Status";
        $announcement->type = "Individual";
        $announcement->description = "Application for " . $user->email . " accepted";
        $announcement->save();
        $receipients = User::where('role', '=', 'admin')->get();
        !is_null($receipients) ? Notification::send($receipients, new GeneralInfo($announcement)) : '';

        return redirect(route('management.application', ['id' => $id]));
    }

    public function reject_application(FlasherInterface $flasher, $id)
    {
        $application = UserApplication::find($id);
        $application->rejected_at = Carbon::now()->format('Y-m-d\TH:i');
        $application->update();

        $builder = $flasher->error("Application Denied", "Done");
        $builder->flash();

        $user = User::where('id', '=', $application->user_id)->first();

        $announcement = new Announcement();
        $announcement->title = "Application Status";
        $announcement->type = "Individual";
        $announcement->description = "Application for " . $user->email . " rejected";
        $announcement->save();
        $receipients = User::where('role', '=', 'admin')->get();
        !is_null($receipients) ? Notification::send($receipients, new GeneralInfo($announcement)) : '';

        return redirect(route('management.application', ['id' => $id]));
    }

    public function destroy(FlasherInterface $flasher, $id)
    {
        UserApplication::where('id', '=', $id)->delete();

        $builder = $flasher->info("Application Deleted", "Done");
        $builder->flash();


        $announcement = new Announcement();
        $announcement->title = "Application Status";
        $announcement->type = "Individual";
        $announcement->description = "Application id " . $id . " Deleted";
        $announcement->save();
        $receipients = User::where('role', '=', 'admin')->get();
        !is_null($receipients) ? Notification::send($receipients, new GeneralInfo($announcement)) : '';

        return redirect(route('management.applications'));
    }
}
