<?php

namespace App\Http\Controllers\Admin;

use Carbon\Carbon;
use App\Models\User;
use App\Http\Controllers\Controller;

class AdminDashboardController extends Controller
{
    private $one_week;

    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:admin']);
        $this->one_week = Carbon::now()->subDays(7);
    }

    public function dashboard()
    {
        $users = (object)[];

        $market_place = $this->getStats('Script', 'publish_status', 'in_marketplace');

        $optioned = $this->getStats('Script', 'publish_status', 'ready');

        $active_users = $this->getStats('User', 'active', true);

        $treatment_sold = $this->getStats('Script', 'publish_status', 'purchased');

        $being_analyzed = $this->getStats('Script', 'publish_status', 'in_review');

        // Users
        $users->screenwriter = $this->getUserStats('screenwriter');
        $users->producers = $this->getUserStats('producer');
        $users->analyst = $this->getUserStats('analyst');
        $users->mentor = $this->getUserStats('mentor');
        $users->total = User::all()->count();
        $recent_total = User::where('created_at','<', $this->one_week)->count();
        $deviation =  $users->total -  $recent_total;
        $users->total_stat =  $deviation > 0 ? '+' . $deviation : $deviation;


        return view('admin.admin_dashboard', [
            'market_place' => $market_place,
            'optioned'     => $optioned,
            'active_users' => $active_users,
            'treatment_sold' => $treatment_sold,
            'being_analyzed' => $being_analyzed,
            'users' => $users
        ]);
    }

    public function getStats($instance, $column, $condition)
    {
        $decorator = 'App\Models\\' . $instance;
        $result = (new $decorator)->where($column, '=', $condition)->count();
        $week_ago = (new $decorator)->where($column, '=', $condition)->where('created_at', '<', $this->one_week)->count();

        $deviation = $result - $week_ago;
        $deviation =  $deviation > 0 ? '+' . $deviation : $deviation;

        return array('result' => $result, 'stat' => $deviation);
    }

    public function getUserStats($role)
    {
        $result = User::where('role', '=', $role)->count();

        $week_ago = User::where('role', '=', $role)->where('created_at', '<', $this->one_week)->count();

        $deviation = $result - $week_ago;
        $deviation =  $deviation > 0 ? '+' . $deviation : $deviation;

        return array('result' => $result, 'stat' => $deviation);
    }
}
