<?php

namespace App\Http\Controllers\Admin\AdminNotifications;

use App\Models\User;
use App\Models\Announcement;
use Illuminate\Http\Request;
use App\Notifications\GeneralInfo;
use Flasher\Prime\FlasherInterface;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Notification;

class AdminNotificationsController extends Controller
{

    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:admin']);
    }
    public function index()
    {
        $announcements = Announcement::all();
        $users = User::all();
        return view('admin.admin_notifications.index', ['announcements' => $announcements, "users" => $users]);
    }


    public function store(FlasherInterface $flasher, Request $request)
    {
        $this->validate($request, [
            "title" => 'required',
            "type" => 'required',
            "description"  => 'required',
        ]);
        $announcement = new Announcement();
        $announcement->title = $request->input('title');
        $announcement->type = $request->input('type');
        $announcement->description = $request->input('description');
        $announcement->save();
        $receipients = null;

        if ($request->input('type') == 'system_wide') {
            $receipients = User::all();
        } else if ($request->input('type') == 'individuals') {
            $receipients = User::find($request->input('individual'));
        } else {

            if ($request->input('user_groups') == 'team') {
                $receipients = User::where('role', '<>', 'admin');
            }
            if ($request->input('type') == 'user_groups') {
                $receipients = User::where('role', '=', $request->input('user_groups'));
            }
        }

        !is_null($receipients) ? Notification::send($receipients, new GeneralInfo($announcement)) : '';

        $builder = $flasher->success("Announcement sent successfully");
        $builder->flash();


        return redirect(route('management.notifications'));
    }
}
