<?php

namespace App\Http\Controllers\Admin\AdminScripts;

use Carbon\Carbon;
use App\Models\User;
use App\Models\Genre;
use App\Models\Script;
use App\Models\BudgetOption;
use App\Models\ScriptRating;
use Illuminate\Http\Request;
use App\Models\ContentRating;
use Illuminate\Support\Facades\DB;
use Flasher\Prime\FlasherInterface;
use App\Http\Controllers\Controller;

class AdminScriptController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:admin']);
    }

    public function index($script_id){

        $script = Script::where('id' ,'=', $script_id)->first();
        $ratings = ScriptRating::where('script_id' ,'=', $script_id)->first();
        $script->elapsed = Carbon::createFromFormat('Y-m-d H:i:s', $script->created_at)->diffForHumans();
        $analysts = User::where('role', '=', 'analyst')->get();
        $analyst_assigned = DB::table('analyst_script_assignment')->where('script_id', '=', $script->id)->first();
        return view('admin.admin_scripts.script', [
            'script' => $script,
            'ratings' => $ratings,
            'analyst_assigned' => $analyst_assigned,
            'analysts' => $analysts,
        ]);
    }

    public function update_status(FlasherInterface $flasher, Request $request, $id)
    {
        $script = Script::find($id);
        if (!empty($script)) {
            $script->publish_status = $request->status;
            $script->update();

            $builder = $flasher->success("Script accepted successfully");
            $builder->flash();
        }
        return redirect(route('management.script', ['id' => $id]));
    }

    public function update_feedback(FlasherInterface $flasher, Request $request, $id)
    {
        $rating = ScriptRating::where('script_id','=', $id)->firstOrCreate(['script_id' => $id]);

        if (!empty($rating)) {
            $rating->feedback = $request->input('feedback');
            $rating->update();

            $builder = $flasher->success("Feedback updated successfully");
            $builder->flash();
        }
        return redirect(route('management.script', ['id' => $id]));
    }

    public function update_marketplace(FlasherInterface $flasher, Request $request, $id)
    {
        $this->validate($request, [
        'genre' => 'required|max:255',
        'mpaa_rating' => 'required|max:255',
        'budget' => 'required|max:255',
        'where' => 'required',
        'pages' => 'required',
        'similarstories' => 'required',
        ]);
        $script = Script::find($id);
        $script->genre = Genre::where('slug', $request->input('genre'))->first()->id;
        $script->content_rating_id = ContentRating::where('slug', $request->input("mpaa_rating"))->first()->id;
        $script->budget_id = BudgetOption::where('slug', $request->input('budget'))->first()->id;
        $script->where = $request->where;
        $script->pages = $request->pages;
        $script->similar_stories = $request->similarstories;
        $script->update();
        $builder = $flasher->success("Marketplace Details updated successfully");
        $builder->flash();
        return redirect(route('management.script', ['id' => $id]));
    }

   public function rating_form(FlasherInterface $flasher, Request $request)
    {
        $data = $request->all();
        $data['script_id'] = $request->input('script_id');

        $rating = ScriptRating::firstOrCreate(['script_id' => $data['script_id']]);
        $rating->update($data);

        $builder = $flasher->success("Script rating info updated successfully");
        $builder->flash();

        return redirect(route('management.script',['id' => $data['script_id'] ]));
    }

    public function assign_analyst(FlasherInterface $flasher, Request $request)
    {
        // Move goes admin
        $analyst_assigned = DB::table('analyst_script_assignment')
            ->where('script_id', '=', $request->script_id)->first();
        if($analyst_assigned) {
            DB::table('analyst_script_assignment')
            ->where('script_id', '=', $request->script_id)
            ->update(['analyst_id' => $request->send_to]);
        }
        else {
            DB::table('analyst_script_assignment')
            ->insert(['script_id' => $request->script_id, 'analyst_id' => $request->send_to]);
        }


        $builder = $flasher->success("Analyst assigned script");
        $builder->flash();

        return redirect()->back();
    }
}
