<?php

namespace App\Http\Controllers\Admin\AdminTeam;

use App\Events\TeamInviteEmail;
use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;

class AdminTeamAddController extends Controller
{
    public function __construct()
    {
        $this->middleware(['superadmin']);
    }
    public function store(Request $request)
    {
        // Fields Validations
        if ($request->has('email')) {

            $this->validate($request, [
                'first_name' => 'bail|required|max:255',
                'last_name' => 'bail|required|max:255',
                'email' => 'bail|required|email|max:255',
                'password' => 'required|confirmed',
                'phone' => ['required', 'regex:/(^(\([0-9]{3}\) |[0-9]{3}-)[0-9]{3}-[0-9]{4}$)|(^[0-9]{10}$)/'],
                'choose_member' => 'required',
            ], [
                'choose_member.required' => 'Select the Member'
            ]);
            
        } else if($request->has('member_email')) {

            // Convert the User Input Phone Number Format to Just Simple Format with Just numbers present

            $pattern = "/(-)|( )|(\()|(\))/i";
            $incoming_phone = $request->memeber_phone;
            $phone = preg_replace($pattern, "", $incoming_phone);

            // Store in Database
            
            $user = User::create([
                'first_name' => $request->member_first_name,
                'last_name' => $request->member_last_name,
                'email' => $request->member_email,
                'phone' => $phone,
                'uid' => $request->member_uid,
                'role' => $request->choose_member,
            ]);

            event(new TeamInviteEmail($user, $request->member_password));
        }
    }
}
