<?php

namespace App\Http\Controllers\Admin\AdminUsers;

use App\Events\TeamInviteEmail;
use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;

class AdminUserAddController extends Controller
{
    public function store(Request $request)
    {
        // Fields Validations
        if ($request->has('email')) {

            $this->validate($request, [
                'first_name' => 'bail|required|max:255',
                'last_name' => 'bail|required|max:255',
                'email' => 'bail|required|email|max:255',
                'password' => 'required|confirmed',
                'phone' => ['required', 'regex:/(^(\([0-9]{3}\) |[0-9]{3}-)[0-9]{3}-[0-9]{4}$)|(^[0-9]{10}$)/'],
                'choose_user' => 'required',
            ], [
                'choose_user.required' => 'Select the User'
            ]);
            
        } else if($request->has('user_email')) {

            // Convert the User Input Phone Number Format to Just Simple Format with Just numbers present

            $pattern = "/(-)|( )|(\()|(\))/i";
            $incoming_phone = $request->user_phone;
            $phone = preg_replace($pattern, "", $incoming_phone);

            // Store in Database

            $user = User::create([
                'first_name' => $request->user_first_name,
                'last_name' => $request->user_last_name,
                'email' => $request->user_email,
                'phone' => $phone,
                'uid' => $request->user_uid,
                'role' => $request->choose_user,
            ]);

            event(new TeamInviteEmail($user, $request->user_password));
        }
    }
}
