<?php

namespace App\Http\Controllers\Analyst\AnalystScripts;

use Carbon\Carbon;
use App\Models\Script;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\ScriptRating;
use Flasher\Prime\FlasherInterface;
use Illuminate\Support\Facades\Session;

class AnalystScriptController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:analyst']);
    }
    public function index($script)
    {
        $script = Script::where('id', '=', $script)->first();
        $script->elapsed = Carbon::createFromFormat('Y-m-d H:i:s', $script->created_at)->diffForHumans();
        $script->ratings = ScriptRating::where('script_id', '=', $script->id)->first();

        return view('analyst.analyst_scripts.script', ['script' => $script]);
    }


    public function update_status(FlasherInterface $flasher,Request $request, $id)
    {
        $script = Script::find($id);

        if (!empty($script)) {
            $script->publish_status = $request->status;
            $script->update();

            $builder = $flasher->success("Script sent to admin");
            $builder->flash();
            return json_encode(['message' => 'updated successfully']);
        } else {
            $builder = $flasher->error("Script not found");
            $builder->flash();
            return json_encode(['message' => 'Script not found'], 400);
        }
    }

    public function update_feedback(FlasherInterface $flasher, Request $request, $id)
    {
        $rating = ScriptRating::firstOrCreate(['script_id' => $id]);

        $rating->feedback = $request->input('feedback');
        $rating->update();

        $builder = $flasher->success("Feedback saved successfully");
        $builder->flash();

        return redirect(route('analyst.script', ['id' => $id]));
    }


    public function rating_form(FlasherInterface $flasher, Request $request)
    {
        $data = $request->all();
        $data['script_id'] = $request->input('script_id');

        $rating = ScriptRating::firstOrCreate(['script_id' => $data['script_id']]);
        $rating->update($data);

        $builder = $flasher->success("Rating saved successfully");
        $builder->flash();

        return redirect(route('analyst.script', ['id' => $data['script_id']]));
    }
}
