<?php

namespace App\Http\Controllers\Analyst\AnalystScripts;

use Carbon\Carbon;
use App\Models\User;
use App\Models\Script;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class AnalystScriptsQueueController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:analyst']);
    }
    public function index()
    {

        $analyst_assigned = DB::table('analyst_script_assignment')->select('id')->get();
        $analysts = User::where('role', '=', 'analyst')->get();
        $assinable_scripts = Script::where('publish_status', '=', 'submitted')->count();

        // Round robin
        $assinable = $assinable_scripts / count($analysts);
        $assinable = $assinable > 5 ? 5 : $assinable;
        $assinable = $assinable == 0 ? 1 : $assinable;

        if ($analyst_assigned->isEmpty()) {

            $scripts = Script::where('publish_status', '=', 'submitted')->limit(ceil($assinable))->get();

            foreach ($scripts as $script) {
                $values = [
                    'analyst_id' => Auth::user()->id,
                    'script_id' => $script->id,
                ];
                DB::table('analyst_script_assignment')->insert($values);
            }

        }

        else {
            $scripts = DB::table('scripts')
                ->where('publish_status', '=', 'submitted')
                ->whereIn('id', function ($query) {
                    $query->select('id')
                        ->from('analyst_script_assignment')
                        ->whereRaw('analyst_script_assignment.analyst_id = ' . Auth::user()->id);
                })
                ->toSql();

        }

        $scripts->inqueue = count($scripts);
        $scripts->inreview = Script::where('publish_status', '=', 'in_review')->count();
        $scripts->sent = Script::where('publish_status', '=', 'ready')->count();

        foreach ($scripts as $script) {
            $uploaded = Carbon::createFromFormat('Y-m-d H:i:s', $script->created_at);
            $scripts->elapsed = $uploaded->diffForHumans();
        }


        return view('analyst.analyst_scripts.scriptsqueue', ['scripts' => $scripts, 'analysts' => $analysts]);
    }
}
