<?php

namespace App\Http\Controllers\Auth\User;

use App\Events\UserRegistered;
use App\Http\Controllers\Controller;
use App\Models\Checklist;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class LoginController extends Controller
{
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    public function index()
    {
        return view('auth.user.login');
    }

    public function store(Request $request)
    {

        if ($request->has('email')) {
            // Fields Validations
            $this->validate($request, [
                'email' => 'bail|required|email|max:255',
                'password' => 'bail|required'
            ]);
        } else if ($request->has('unverify_user_uid')) {
            // Take Phone Number based on Uid
            $results = DB::table('users')
                ->select('phone')
                ->where('uid', $request->unverify_user_uid)
                ->get();

            foreach ($results as $result) {
                $phone = $result->phone;
            }

            return $phone;
        } else if ($request->has('verified') && $request->has('uid')) {

            // Login User
            $results = DB::table('users')
                ->select('id', 'role')
                ->where('uid', $request->uid)
                ->get();

            if (!$results->isEmpty()) {

                foreach ($results as $result) {
                    $id = $result->id;
                    $role = $result->role;
                }

                if ($role == null || $role == 'screenwriter' || $role == 'producer') {

                    DB::table('users')
                        ->where('uid', $request->uid)
                        ->update([
                            'verified' => true
                        ]);

                    auth()->loginUsingId(['id' => $id]);
                } else {
                    return 'Not Found';
                }
            } else {
                return 'Not Found';
            }
        } else if ($request->has('user_email')) {
            if ($request->mf > 0) {
                $results = DB::table('users')
                    ->select('id')
                    ->where('uid', $request->user_uid)
                    ->get();

                foreach ($results as $result) {
                    $id = $result->id;
                }

                auth()->loginUsingId($id, $request->remember);
            } else {
                return "MultiFactor Required";
            }
        } else if ($request->has('provider_email')) {

            $results = DB::table('users')
                ->select('id')
                ->where('uid', $request->provider_uid)
                ->get();

            if (!$results->isEmpty()) {
                foreach ($results as $result) {
                    $id = $result->id;
                }

                auth()->loginUsingId(['id' => $id]);
            } else {
                // Store in Database
                $user = User::create([
                    'first_name' => $request->provider_first_name,
                    'last_name' => $request->provider_last_name,
                    'email' => $request->provider_email,
                    'phone' => null,
                    'uid' => $request->provider_uid,
                    'role' => null,
                ]);

                //Initiate Checklist
                Checklist::create([
                    'user_id' => $user->id
                ]);

                event(new UserRegistered($user));

                auth()->loginUsingId(['id' => $user->id]);
            }
        }
    }
}
