<?php

namespace App\Http\Controllers\Auth\User;

use App\Events\UserRegistered;
use App\Http\Controllers\Controller;
use App\Models\Checklist;
use App\Models\User;
use Google\Cloud\PubSub\PubSubClient;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class SignupController extends Controller
{
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    public function index()
    {
        return view('auth.user.signup');
    }

    public function store(Request $request)
    {
        if ($request->has('email')) {
            // Fields Validations
            $this->validate($request, [
                'first_name' => 'bail|required|max:255',
                'last_name' => 'bail|required|max:255',
                'email' => 'bail|required|email|max:255',
                'password' => 'required|confirmed',
                'phone' => ['required', 'regex:/(^(\([0-9]{3}\) |[0-9]{3}-)[0-9]{3}-[0-9]{4}$)|(^[0-9]{10}$)/'],
                'terms' => 'accepted',
            ]);
        } else if (($request->has('user_email'))) {

            // Convert the User Input Phone Number Format to Just Simple Format with Just numbers present

            $pattern = "/(-)|( )|(\()|(\))/i";
            $incoming_phone = $request->user_phone;
            $phone = preg_replace($pattern, "", $incoming_phone);

            // Store in Database
            $user = User::create([
                'first_name' => $request->user_first_name,
                'last_name' => $request->user_last_name,
                'email' => $request->user_email,
                'phone' => $phone,
                'uid' => $request->user_uid,
                'role' => null,
            ]);

            //Initiate Checklist
            Checklist::create([
                'user_id' => $user->id
            ]);

            event(new UserRegistered($user));
        } else if ($request->has('provider_email')) {

            $this->validate($request, [
                'provider_email' => 'unique:users,email',
            ]);

            // Store in Database
            $user = User::create([
                'first_name' => $request->provider_first_name,
                'last_name' => $request->provider_last_name,
                'email' => $request->provider_email,
                'phone' => null,
                'uid' => $request->provider_uid,
                'role' => null,
            ]);

            //Initiate Checklist
            Checklist::create([
                'user_id' => $user->id
            ]);

            event(new UserRegistered($user));

            auth()->loginUsingId(['id' => $user->id]);
        }
    }
}
