<?php

namespace App\Http\Controllers\Dwolla\Screenwriter;

use App\Http\Controllers\Controller;
use App\Models\Checklist;
use App\Models\User;
use App\Services\Dwolla\Customers\CustomerApi;
use App\Services\Dwolla\FundingSources\CreateFundingSource;
use App\Services\Dwolla\FundingSources\FundingSource;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class PersonalVerifiedController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:screenwriter']);
        $this->middleware(['dowalla.auth:NotRequired']);
    }

    public function index()
    {
        return view('dwolla.screenwriter.index');
    }

    public function store(Request $request)
    {
        // Fields Validations
        $this->validate($request, [
            'address' => 'bail|required|max:255',
            'city' => 'bail|required|max:255',
            'state' => 'required|max:2',
            'postal_code' => 'required',
            'dob' => 'required',
            'ssn' => 'bail|required|max:4',
            'terms' => 'accepted'
        ]);

        // Changing format of Date to Dwolla Required Format
        $orgDate = $request->dob;  
        $newDate = date("Y-m-d", strtotime($orgDate)); 

        // Initialize Customer API
        $InitCustomersApi = new CustomerApi();
        $customersApi = $InitCustomersApi::InitializeCustomerApi();

        // Get Current User Details
        $current_user = Auth::user();

        //Create New Customer 
        $newCustomer = $customersApi->create([
            'firstName' => $current_user->first_name,
            'lastName' => $current_user->last_name,
            'email' => $current_user->email,
            'type' => 'personal',
            'address1' => $request->address,
            'city' => $request->city,
            'state' => 'NY',
            'postalCode' => $request->postal_code,
            'dateOfBirth' => $newDate,

            # For the first attempt, only the
            # last 4 digits of SSN required

            # If the entire SSN is provided,
            # it will still be accepted
            'ssn' => $request->ssn
        ]);

        $customer_Id = basename(''.$newCustomer.'');

        User::where('id', $current_user->id)->update(['dwolla_customer_id' => $customer_Id]);

        return redirect()->route('screenwriter.index');

        // Get Funding Sources

        // $fs = new FundingSource;
        // $listfs = $fs::bankFundingSource('737d3139-f6b5-407f-8b84-27719965c6cd');
        // dd($listfs);

        // // Create A funding Source

        // $fundingsourceapi = new CreateFundingSource();
        // $result = $fundingsourceapi::createFundingSource('4e242ac9-6acc-4b21-afb9-44f01d74cc40', 222222226, 123456789, 'checking', 'John Doe');
        // print_r($result);

    }
}
