<?php

namespace App\Http\Controllers\Producer\ProducerForms;

use App\Http\Controllers\Controller;
use App\Models\ProducerApplication;
use App\Models\UserApplication;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class ProducerNonUnionFormController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:producer']);
        $this->middleware(['producer.form.status']);
    }
    public function index()
    {
        $id = Auth::user()->id;

        $results = DB::table('producer_applications')
            ->select('approved')
            ->where('user_id', $id)
            ->get();

        if ($results->isNotEmpty()) {
            foreach ($results as $result) {
                $status = $result->approved;
            }
        } else {
            $status = 'No Form';
        }

        return view('producer.producer_forms.nonunion', [
            'status' => $status,
        ]);
    }

    public function store(Request $request)
    {

        $this->validate($request, [
            'pronoun' => 'required',
            'country' =>  'required',
            'experience' => 'required',
            'imdb_link' => ['required', 'regex:/^(?:http:\/\/|https:\/\/)?(?:www\.)?(?:imdb.com)/mi'],
            'meeting_available' => 'required',
            'any_saying' => 'required',
            'terms' => 'accepted'
        ]);

        $id = Auth::user()->id;

        if (ProducerApplication::where('user_id',  $id)->doesntExist()) {
            $producer_application = ProducerApplication::create([
                'country' => $request->country,
                'experienced' => $request->experience,
                'imdb_link' => $request->imdb_link,
                'meeting_preference' => $request->meeting_available,
                'pronoun' => $request->pronoun,
                'more' => $request->any_saying,
                'producer_type' => 'non-union',
                'user_id' => $id,
            ]);

            $application_id = $producer_application->id;
            $application_type = 'producer_applications';

            //Entry in User Application table
            UserApplication::create([
                'user_id' => $id,
                'applicationable_id' => $application_id,
                'applicationable_type' => $application_type,
            ]);

            return back()->with('status', 'success');
        } else {
            return back()->with('status', 'success');
        }
    }
}
