<?php

namespace App\Http\Controllers\Screenwriter\ScreenwriterScripts;

use App\Events\EsignatureContract;
use App\Http\Controllers\Controller;
use App\Models\Script;
use App\Services\CloudStorage\CloudStorageServices;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Storage;

class ScreenwriterDraftScriptController extends Controller
{
    use CloudStorageServices;
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:screenwriter']);
        $this->middleware(['dowalla.auth:Required']);
    }

    public function index($id)
    {
        $current_user = Auth::user();

        // Full Name of User
        $fullname = $current_user->fullname;

        // User Scripts
        $ScriptResult = Script::where('id', $id);

        if ($ScriptResult) {
            $ScriptResult = $ScriptResult->where('user_id', $current_user->id)
                ->get();

            if (!$ScriptResult->isEmpty()) {
                foreach ($ScriptResult as $scriptresult) {
                    if ($scriptresult->publish_status == 'denied' || $scriptresult->publish_status == 'draft') {
                        $script = $scriptresult;
                    } else {
                        $script = false;
                    }
                }
            } else {
                $script = false;
            }
        } else {
            $script = false;
        }

        return view('screenwriter.screenwriter_scripts.scriptdraft', [
            'fullname' => $fullname,
            'script' => $script,
        ]);
    }

    public function store(Request $request, $id)
    {

        if ($request->has('treatment') || $request->has('script')) {

            if ($request->has('treatment' && !$request->has('script'))) {

                $this->validate($request, [
                    'genre' => 'required',
                    'pages' => 'required',
                    'mpaa_rating' => 'required',
                    'budget' => 'required',
                    'timeline' => 'required',
                    'where' => 'required',
                    'title' => 'required',
                    'synopsis' => 'required',
                    'tagline' => 'required',
                    'logline' => 'required',
                    'treatment' => 'required|mimes:pdf|max:1024',
                ]);

                $treatment_name = pathinfo($request->file('treatment')->getClientOriginalName(), PATHINFO_FILENAME);
                $treatment_unique_name = (time() * 13) . $treatment_name . '.pdf';

                $current_user = Auth::user();

                // Deleting the Previous FIles from Bucket
                $Script = DB::table('scripts')->where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->get();

                foreach ($Script as $script) {
                    if($script->publish_status == 'draft' || $script->publish_status == 'denied'){
                        $treatment_name = $script->treatment;
                    }else{
                        return redirect('/screenwriter/scripts')->with('error_status', 'success');
                    }
                }

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                $object = $bucket->object($treatment_name);
                $object->delete();

                // Update the Database
                $script = Script::where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->where('publish_status', 'draft')
                    ->update([
                        'genre' => $request->genre,
                        'pages' => $request->pages,
                        'content_ratings' => $request->mpaa_rating,
                        'budget' => $request->budget,
                        'timeline' => $request->timeline,
                        'where' => $request->where,
                        'title' => $request->title,
                        'synopsis' => $request->synopsis,
                        'tagline' => $request->tagline,
                        'logline' => $request->logline,
                        'treatment' => $treatment_unique_name,
                    ]);

                // Store into Application Storage
                $request->file('treatment')->storeAs('', $treatment_unique_name, 'local');

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                // For Script FIle Upload
                $bucket->upload(
                    fopen(storage_path('app') . '/' . $treatment_unique_name, 'r'),
                    [
                        'name' => 'treatments/' . $treatment_unique_name . '',
                    ]
                );

                // Deleting the File from application storage
                Storage::disk('local')->delete($treatment_unique_name);

                return redirect(Route('screenwriter.scripts'));
            } else if ($request->has('script') && !$request->has('treatment')) {

                $this->validate($request, [
                    'genre' => 'required',
                    'pages' => 'required',
                    'mpaa_rating' => 'required',
                    'budget' => 'required',
                    'timeline' => 'required',
                    'where' => 'required',
                    'title' => 'required',
                    'synopsis' => 'required',
                    'tagline' => 'required',
                    'logline' => 'required',
                    'script' => 'required|mimes:pdf|max:1024'
                ]);

                $script_name = pathinfo($request->file('script')->getClientOriginalName(), PATHINFO_FILENAME);
                $script_unique_name = (time() * 13) . $script_name . '.pdf';

                $current_user = Auth::user();

                // Deleting the Previous FIles from Bucket
                $Script = DB::table('scripts')->where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->get();

                foreach ($Script as $script) {
                    if ($script->publish_status == 'draft' || $script->publish_status == 'denied') {
                        $script_name = $script->script;
                    } else {
                        return redirect('/screenwriter/scripts')->with('error_status', 'success');
                    }
                }

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                $object = $bucket->object($script_name);
                $object->delete();


                // Update the Database
                $script = Script::where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->where('publish_status', 'draft')
                    ->update([
                        'genre' => $request->genre,
                        'pages' => $request->pages,
                        'content_ratings' => $request->mpaa_rating,
                        'budget' => $request->budget,
                        'timeline' => $request->timeline,
                        'where' => $request->where,
                        'title' => $request->title,
                        'synopsis' => $request->synopsis,
                        'tagline' => $request->tagline,
                        'logline' => $request->logline,
                        'script' => $script_unique_name,
                    ]);

                // Store into Application Storage
                $request->file('script')->storeAs('', $script_unique_name, 'local');

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                // For Script FIle Upload
                $bucket->upload(
                    fopen(storage_path('app') . '/' . $script_unique_name, 'r'),
                    [
                        'name' => 'scripts/' . $script_unique_name . '',
                    ]
                );

                // Deleting the File from application storage
                Storage::disk('local')->delete($script_unique_name);

                return redirect(Route('screenwriter.scripts'));
            } else {

                $this->validate($request, [
                    'genre' => 'required',
                    'pages' => 'required',
                    'mpaa_rating' => 'required',
                    'budget' => 'required',
                    'timeline' => 'required',
                    'where' => 'required',
                    'title' => 'required',
                    'synopsis' => 'required',
                    'tagline' => 'required',
                    'logline' => 'required',
                    'treatment' => 'required|mimes:pdf|max:1024',
                    'script' => 'required|mimes:pdf|max:1024'
                ]);

                //Adjusting the File Name
                $treatment_name = pathinfo($request->file('treatment')->getClientOriginalName(), PATHINFO_FILENAME);
                $treatment_unique_name = (time() * 13) . $treatment_name . '.pdf';

                $script_name = pathinfo($request->file('script')->getClientOriginalName(), PATHINFO_FILENAME);
                $script_unique_name = (time() * 13) . $script_name . '.pdf';

                $current_user = Auth::user();

                // Deleting the Previous FIles from Bucket
                $Script = DB::table('scripts')->where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->get();

                foreach ($Script as $script) {
                    if ($script->publish_status == 'draft' || $script->publish_status == 'denied') {
                        $treatment_name = $script->treatment;
                        $script_name = $script->script;
                    } else {
                        return redirect('/screenwriter/scripts')->with('error_status', 'success');
                    }
                }

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                $object = $bucket->object($treatment_name);
                $object->delete();

                $object = $bucket->object($script_name);
                $object->delete();

                // Update the Database
                $script = Script::where('user_id', $current_user->id)
                    ->where('id', $id)
                    ->where('publish_status', 'draft')
                    ->update([
                        'genre' => $request->genre,
                        'pages' => $request->pages,
                        'content_ratings' => $request->mpaa_rating,
                        'budget' => $request->budget,
                        'timeline' => $request->timeline,
                        'where' => $request->where,
                        'title' => $request->title,
                        'synopsis' => $request->synopsis,
                        'tagline' => $request->tagline,
                        'logline' => $request->logline,
                        'treatment' => $treatment_unique_name,
                        'script' => $script_unique_name,
                    ]);

                // Store into Application Storage
                $request->file('treatment')->storeAs('', $treatment_unique_name, 'local');
                $request->file('script')->storeAs('', $script_unique_name, 'local');

                // Initilaze Cloud Storage Client and choosing Bucket
                $client = self::CloudStorageConfiguration();
                $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

                // For Treatment FIle Upload
                $bucket->upload(
                    fopen(storage_path('app') . '/' . $treatment_unique_name, 'r'),
                    [
                        'name' => 'treatments/' . $treatment_unique_name . '',
                    ]
                );

                // For Script FIle Upload
                $bucket->upload(
                    fopen(storage_path('app') . '/' . $script_unique_name, 'r'),
                    [
                        'name' => 'scripts/' . $script_unique_name . '',
                    ]
                );

                // Deleting the File from application storage
                Storage::disk('local')->delete($treatment_unique_name, $script_unique_name);

                return redirect(Route('screenwriter.scripts'));
            }
        } else {

            $this->validate($request, [
                'genre' => 'required',
                'pages' => 'required',
                'mpaa_rating' => 'required',
                'budget' => 'required',
                'timeline' => 'required',
                'where' => 'required',
                'title' => 'required',
                'synopsis' => 'required',
                'tagline' => 'required',
                'logline' => 'required',
            ]);

            $current_user = Auth::user();

            $script = Script::where('user_id', $current_user->id)
                ->where('id', $id)
                ->where('publish_status', 'draft')
                ->update([
                    'genre' => $request->genre,
                    'pages' => $request->pages,
                    'content_ratings' => $request->mpaa_rating,
                    'budget' => $request->budget,
                    'timeline' => $request->timeline,
                    'where' => $request->where,
                    'title' => $request->title,
                    'synopsis' => $request->synopsis,
                    'tagline' => $request->tagline,
                    'logline' => $request->logline,
                ]);

            return redirect(Route('screenwriter.scripts'));
        }
    }

    public function updateDraft($id)
    {
        $current_user = Auth::user();
        
        // Esignature Work
        $event = event(new EsignatureContract($current_user, $id));

        return redirect('/screenwriter/scripts')->with('contract_status', 'success');
    }

    public function updateDenied($id)
    {
        $current_user = Auth::user();

        Script::where('user_id', $current_user->id)
            ->where('id', $id)
            ->where('publish_status', 'denied')
            ->update([
                'publish_status' => 'submitted',
                'submissions' => 2,
            ]);

        return redirect('/screenwriter/scripts')->with('submit_status', 'success');
    }

    public function delete($id)
    {
        $current_user = Auth::user();

        $Script = DB::table('scripts')->where('user_id', $current_user->id)
            ->where('id', $id)
            ->where('publish_status', 'draft')
            ->get();

        foreach ($Script as $script) {
            $treatment_name = $script->treatment;
            $script_name = $script->script;
        }

        // Initilaze Cloud Storage Client and choosing Bucket
        $client = self::CloudStorageConfiguration();
        $bucket = $client->bucket(env('GOOGLE_CLOUD_STORAGE_BUCKET'));

        $object = $bucket->object($treatment_name);
        $object->delete();

        $object = $bucket->object($script_name);
        $object->delete();

        DB::table('scripts')->where('user_id', $current_user->id)
            ->where('id', $id)
            ->where('publish_status', 'draft')
            ->delete();

        return redirect('/screenwriter/scripts')->with('delete_status', 'success');
    }
}
