<?php

namespace App\Http\Controllers\Screenwriter\ScreenwriterWallet;

use App\Http\Controllers\Controller;
use App\Models\DwollaTransaction;
use App\Models\User;
use App\Services\Dwolla\FundingSources\FundingSource;
use App\Services\Dwolla\Transfer\TransferApi;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ScreenwriterWalletController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role:screenwriter']);
        $this->middleware(['dowalla.auth:Required']);
    }

    public function index()
    {
        $current_user = Auth::user();
        $user_id = $current_user->id;
        $fullname = $current_user->fullname;
        $dwolla_customer_id = $current_user->dwolla_customer_id;

        $fs = new FundingSource();
        // Get Balance
        $balance = $fs::getBalance($dwolla_customer_id);

        //Check that bank funding source added or not
        $funding_source = $fs::bankFundingSource($dwolla_customer_id);

        // Get Transactions
        $dwolla_transactions = DwollaTransaction::where('seller_id', $user_id)
            ->orderBy('created_at', 'DESC')->get();

        if ($dwolla_transactions->isNotEmpty()) {
            $transferApi = new TransferApi();
            $transactions_details = $transferApi::getTransactionDetails($dwolla_customer_id);
            foreach ($dwolla_transactions as $index => $dw_trans) {
                $transactions_details[$index]->{"payment_name"} = $dw_trans->payment_name;
            }
        }

        return view('screenwriter.screenwriter_wallets.index', [
            'fullname' => $fullname,
            'balance' => $balance,
            'bankSource' => $funding_source,
            'transactions' => $transactions_details,
        ]);
    }

    public function addBank(Request $request)
    {
        // Validations
        $this->validate($request, [
            'screenwriter_routing_number' => 'required',
            'screenwriter_account_number' => 'required'
        ], [
            'screenwriter_routing_number.required' => 'Routing Number is Required',
            'screenwriter_account_number.required' => 'Account Number is Required'
        ]);

        $current_user = Auth::user();
        // Check Funding Source
        if (!$current_user->dwolla_funding_source_id) {

            // Add Funding Source
            $fs = new FundingSource();
            $fs_Response = $fs::createFundingSource(
                $current_user->dwolla_customer_id,
                $request->screenwriter_routing_number,
                $request->screenwriter_account_number,
                'checking',
                $current_user->first_name
            );

            if ($fs_Response) {

                $fs_Id = basename('' . $fs_Response . '');
                User::where('id', $current_user->id)
                    ->update([
                        'dwolla_funding_source_id'  => $fs_Id
                    ]);
                return 'success';
            }
        }else{
            return 'failure';
        }
    }
}
