<?php

namespace App\Http\Controllers\Stripe;

use Stripe\Stripe;
use App\Models\User;
use Illuminate\Http\Request;
use Stripe\BillingPortal\Session;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use App\Services\Stripe\CreateCustomer\CreateCustomer;
use App\Services\Stripe\CreateSubscriptions\ProducerSubscriptions\PremiumSubscription\AnnualBasic;
use App\Services\Stripe\CreateSubscriptions\ProducerSubscriptions\PremiumSubscription\AnnualPremium;
use App\Services\Stripe\CreateSubscriptions\ProducerSubscriptions\PremiumSubscription\BasicSemiAnnual;
use App\Services\Stripe\CreateSubscriptions\ProducerSubscriptions\PremiumSubscription\SemiAnnualPremium;
use App\Services\Stripe\CreateSubscriptions\ScreenwriterSubscriptions\SemiAnnualSubscription;

class ProducerStripeController extends Controller
{
    private $plans = ['basic-semi-annual','basic-annual', 'premium-semi-annual', 'premium-annual'];

    public function index()
    {
        return view('stripe.index');
    }

    public function create_portal_session(Request $request)
    {
        $user = User::find(Auth::user()->id);

        $customer_id = '';

        if ($user->stripe_customer_id == null) {
            $customer = CreateCustomer::createCustomer($user->email, $user->fullname, $user->country);
            $user->stripe_customer_id = $customer->id;
            $user->update();
            $customer_id =  $customer->id;
        } else {
            $customer_id =  $user->stripe_customer_id;
        }

        Stripe::setApiKey(config('services.stripe.key'));

        $session = Session::create([
            'customer' => $customer_id,
            'return_url' => route(Auth::user()->role.'.settings'),
        ]);

        return redirect(url($session->url));
    }

    public function create_subscription(Request $request)
    {
        $user =  User::find(Auth::user()->id);

        // Check plan
        if (!in_array($request->plan, $this->plans)) {
            return response(['message' => 'Invalid plan'], 400);
        }

        // Create customer
        $customer_id = '';
        if ($user->stripe_customer_id == null) {

            $customer = CreateCustomer::createCustomer($user->email, $user->fullname, $user->country);
            $user->stripe_customer_id = $customer->id;
            $user->update();

            $customer_id =  $customer->id;
        } else {
            $customer_id =  $user->stripe_customer_id;
        }

        // Retrieve existing subscription
        $user_sub = DB::table('subscriptions')->where('user_id', '=', $user->id)->first();

        if (!empty($user_sub) && $user_sub->stripe_status != 'incomplete') {
            $subscription = $this->stripe->subscriptions->retrieve(
                $user_sub->stripe_id,
                []
            );
            $invoice = $this->stripe->invoices->retrieve(
                $subscription->latest_invoice,
                []
            );
            $paymentIntent = $this->stripe->paymentIntents->retrieve(
                $invoice->payment_intent,
                []
            );
            return json_encode($paymentIntent);
        }

        // Create Subscription
        $subscription = null;

        if ($request->plan == 'premium-semi-annual') {
            $subscription = SemiAnnualPremium::createSubscription($customer_id);
        }

        else if ($request->plan == 'premium-annual') {
            $subscription = AnnualPremium::createSubscription($customer_id);
        }

        else if ($request->plan == 'basic-semi-annual') {
            $subscription = BasicSemiAnnual::createSubscription($customer_id);
        }

        else {
            $subscription = AnnualBasic::createSubscription($customer_id);
        }

        return json_encode($subscription->latest_invoice['payment_intent']);
    }
}
