<?php

namespace App\Http\Controllers\Stripe;

use Stripe\Stripe;
use App\Models\User;
use Illuminate\Http\Request;
use Stripe\BillingPortal\Session;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use App\Services\Stripe\CreateCustomer\CreateCustomer;
use App\Services\Stripe\CreateSubscriptions\ScreenwriterSubscriptions\AnnualSubscription;
use App\Services\Stripe\CreateSubscriptions\ScreenwriterSubscriptions\SemiAnnualSubscription;

class ScreenwriterStripeController extends Controller
{
    private $plans = ['semi-annual', 'annual'];

    public function create_portal_session()
    {
        $user = User::find(Auth::user()->id);

        $customer_id = '';

        if ($user->stripe_customer_id == null) {
            $customer = CreateCustomer::createCustomer($user->email, $user->fullname, $user->country);
            $user->stripe_customer_id = $customer->id;
            $user->update();
            $customer_id =  $customer->id;
        } else {
            $customer_id =  $user->stripe_customer_id;
        }

        Stripe::setApiKey(config('services.stripe.key'));

        $session = Session::create([
            'customer' => $customer_id,
            'return_url' => route(Auth::user()->role.'.settings'),
        ]);

        return redirect(url($session->url));
    }


    public function create_subscription(Request $request)
    {
        $user =  User::find(Auth::user()->id);

        // Check plan
        if (!in_array($request->plan, $this->plans)) {
            return response(['message' => 'Invalid plan'], 400);
        }

        // Create customer
        $customer_id = '';
        if ($user->stripe_customer_id == null) {
            $customer = CreateCustomer::createCustomer($user->email, $user->fullname, $user->country);
            $user->stripe_customer_id = $customer->id;
            $user->update();
            $customer_id = $customer->id;
        } else {
            $customer_id = $user->stripe_customer_id;
        }

        // Retrieve existing subscription
        $user_sub = DB::table('subscriptions')->where('user_id', '=', $user->id)->first();

        if (!empty($user_sub) && $user_sub->stripe_status != 'incomplete') {
            $subscription = $this->stripe->subscriptions->retrieve(
                $user_sub->stripe_id,
                []
            );
            $invoice = $this->stripe->invoices->retrieve(
                $subscription->latest_invoice,
                []
            );
            $paymentIntent = $this->stripe->paymentIntents->retrieve(
                $invoice->payment_intent,
                []
            );
            return json_encode($paymentIntent);
        }

        // Env Secret Name
        $subscription = null;

        if ($request->plan == 'annual') {
            $subscription = AnnualSubscription::createSubscription($customer_id);
        }

        if ($request->plan == 'semi-annual') {
            $subscription = SemiAnnualSubscription::createSubscription($customer_id);
        }

        return json_encode($subscription->latest_invoice['payment_intent']);
    }
}
