<?php

namespace App\Http\Controllers\Stripe;

use Carbon\Carbon;
use Stripe\Webhook;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Config;
use Stripe\Exception\UnexpectedValueException;
use Stripe\Exception\SignatureVerificationException;

class StripeWebhookController extends Controller
{
    private $stripe;
    private $products;

    public function __construct()
    {
        $this->products = Config::get('services.stripe.subscriptions');
    }

    public function webhooks(Request $request)
    {
        $endpoint_secret = config('services.stripe.webhook_secret');

        try {
            $event = Webhook::constructEvent(
                $request->getContent(),
                $request->header('stripe-signature'),
                $endpoint_secret
            );
        }

        catch (UnexpectedValueException $e) {
            Log::debug($e->getMessage());
            return response(json_encode(['message' => 'invalid payload'], 400));
        }

        catch (SignatureVerificationException $e) {
            Log::error($e->getMessage());
            return response(json_encode(['message' => 'signature verificationfailed'], 400));
        }

        $object = $event->data->object;

        // Handle the event
        switch ($event->type) {
            case 'invoice.paid':

                $subscr_type = '';
                foreach ($this->products as $subscription) {

                    if ($object->lines->data[0]['plan']['id'] == $subscription['price']) {

                        $haystack = $subscription['name'];

                        if (strpos($haystack, 'BASIC')) {
                            $subscr_type = 'basic';
                        } else if (strpos($haystack, 'PREM')) {
                            $subscr_type = 'premium';
                        } else if (strpos($haystack, 'ANNU')) {
                            $subscr_type = 'annual';
                        } else if (strpos($haystack, 'SEMI')) {
                            $subscr_type = 'semi_annual';
                        }
                        break;
                    }
                }

                $user =  User::where('stripe_customer_id', '=', $object->customer)->first();

                $values = array(
                    'user_id' => $user->id,
                    'name' => $subscr_type,
                    'stripe_id' => $object->subscription,
                    'stripe_status' => 'active',
                    'current_period_start' => Carbon::createFromTimestamp($object->current_period_start)->toDateTimeString(),
                    'current_period_end' => Carbon::createFromTimestamp($object->current_period_end)->toDateTimeString(),
                    'stripe_price' => $object->lines->data[0]['price']->id,
                );


                $data = DB::table('subscriptions')->insert($values);

                break;

            case 'customer.subscription.updated':

            default:

                Log::info('Passed ' . $event->type);
        }

        return response(['message' => 'completed'], 200);
    }
}
