<?php
/*
 * Copyright (c) 2022. WoAccelerator, Inc. All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
namespace App\Jobs\User;

use App\Models\User;
use App\Services\SendInBlue\SendInBlueContactService;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;

class SyncUserContactWithSendInBlue implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * @var User $user
     */
    public $user;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(User $user)
    {
        $this->user = $user;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $contactService = app(SendInBlueContactService::class);
        if (!$this->user->send_in_blue_contact_id) {
            $contact = null;

            try {
                $contact = $contactService->findContactByUser($this->user);
            } catch (\Exception $exception) {
                Log::debug('Contact not found with id: ' . $contactService->getContactIdentifier($this->user));
            }

            if (!isset($contact)) {
                $contact = $contactService->createContactFromUser($this->user);
            }

            $this->user->send_in_blue_contact_id = $contact->getId();
            $this->user->save();
        } else {
            $contactService->updateContactFromUser($this->user);
        }

    }
}
