<?php
/*
 * Copyright (c) 2022. WoAccelerator, Inc. All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
namespace App\Models\Concerns;

use App\Models\User;
use Carbon\Carbon;

trait StripeSubs
{
    public function subscribe(String $plan, String $success_url, String $cancel_url)
    {
        $productId = null;
        $priceId = null;

        if ($this->stripe_id == null) {
            if (!$this->hasStripeId()) {
                $this->createAsStripeCustomer(['name' => $this->name()]);
            } else {
                abort(403, 'Checkout not enabled for user. Try getting verified or approval for script first.');
            }
        }

        if ($this->account_type == User::ACCOUNT_TYPE_WRITER_NON_PROGRAM) {
            if ($this->subscribed(config('stripe.subscriptions.writer_semi_annual.name')) ||
                $this->subscribed(config('stripe.subscriptions.writer_annual.name'))) {
                abort(403, 'Active subscription found!');
            }
            switch ($plan) {
                case 'writer_semi_annual':
                    $productId = config('stripe.subscriptions.writer_semi_annual.name');
                    $priceId = config('stripe.subscriptions.writer_semi_annual.price');
                    break;
                case 'writer_annual':
                    $productId = config('stripe.subscriptions.writer_annual.name');
                    $priceId = config('stripe.subscriptions.writer_annual.price');
                    break;
                default:
                    abort(403, 'Plan not supported for account type!');
            }
        } else {
            if (($this->trial_ends_at > now()) ||
                $this->subscribed(config('stripe.subscriptions.producer_basic_annual.name')) ||
                $this->subscribed(config('stripe.subscriptions.producer_premium_annual.name')) ||
                $this->subscribed(config('stripe.subscriptions.producer_basic_semi_annual.name')) ||
                $this->subscribed(config('stripe.subscriptions.producer_premium_semi_annual.name'))
            ) {
                abort(403, 'Active subscription found!');
            }
            switch ($plan) {
                case 'producer_basic_annual':
                    $productId = config('stripe.subscriptions.producer_basic_annual.name');
                    $priceId = config('stripe.subscriptions.producer_basic_annual.price');
                    break;
                case 'producer_basic_semi_annual':
                    $productId = config('stripe.subscriptions.producer_basic_semi_annual.name');
                    $priceId = config('stripe.subscriptions.producer_basic_semi_annual.price');
                    break;
                case 'producer_premium_annual':
                    if ($this->account == User::ACCOUNT_TYPE_NON_GUILD_PRODUCER) {
                        abort(403, 'Non guild members are not allowed to subscribe to premium plan.');
                    }
                    $productId = config('stripe.subscriptions.producer_premium_annual.name');
                    $priceId = config('stripe.subscriptions.producer_premium_annual.price');
                    break;
                case 'producer_premium_semi_annual':
                    if ($this->account == User::ACCOUNT_TYPE_NON_GUILD_PRODUCER) {
                        abort(403, 'Non guild members are not allowed to subscribe to premium plan.');
                    }
                    $productId = config('stripe.subscriptions.producer_premium_semi_annual.name');
                    $priceId = config('stripe.subscriptions.producer_premium_semi_annual.price');
                    break;
                default:
                    abort(403, 'Plan not supported for account type!');
            }
        }

        $res = $this->newSubscription(
            $productId,
            $priceId
        )->checkout([
            'success_url' => $success_url,
            'cancel_url' => $cancel_url,
        ]);

        return ['checkout_url' => $res->url];
    }

    //This is the date that producers monnthly subscriptions will be active regardless of signup date
    //and there will be no more free trials.
    public function startTrial()
    {
        $this->trial_ends_at = Carbon::createFromDate(2022, 12, 15); 
    }
}
