<?php

namespace App\Models;

use App\Models\Concerns\Uuids;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Carbon;

class ScriptOrder extends Model
{
    use Uuids, HasFactory;

    const TYPE_TREATMENT = 'treatment';
    const TYPE_SCREENPLAY = 'screenplay';
    const TYPE_EXTENSION = 'extension';
    const PERIOD_SIX_MONTHS = '6_months';
    const PERIOD_TWELVE_MONTHS = '12_months';

    protected $hidden = ['stripe_id'];

    protected $fillable = [
        'user_id',
        'checkout',
        'period',
        'checkout_url',
        'checkout_until',
        'checkout_amount',
    ];

    protected $casts = [
        'script_id' => 'string',
        'user_id' => 'string',
        'stripe_id' => 'string',
        'checkout' => 'string',
        'period' => 'string',
        'checkout_amount' => 'integer',
        'checkout_url' => 'string',
        'checkout_until' => 'datetime',
        'checkout_completed' => 'datetime',
        'checkout_canceled' => 'datetime'
    ];

    public function script()
    {
        return $this->belongsTo(Script::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function esignatures()
    {
        return $this->hasMany(SignatureRequest::class, 'script_order_id', 'id');
    }

    public function completed()
    {
        $this->checkout_completed = Carbon::now();
    }

    public function canceled()
    {
        // TODO: cancel the stripe session as well
        $this->checkout_canceled = Carbon::now();
    }
    public static function createScriptOrder($data)
    {
        return  $scriptOrder = ScriptOrder::create([
            'user_id' => $data['user_id'],
            'script_id' => $data['script_id'],
            'dwolla_transfer_id' => $data['transfer_id']
        ]);
    }
}
