<?php
/*
 * Copyright (c) 2022. WoAccelerator, Inc. All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

namespace App\Models;

use App\Models\Subscription;
use FontLib\Table\Type\name;
use Illuminate\Support\Facades\DB;
use App\Models\Concerns\StripeSubs;
use Illuminate\Support\Facades\Auth;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use HasFactory, Notifiable, SoftDeletes;
    use StripeSubs;

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = [
        'first_name',
        'last_name',
        'email',
        'phone',
        'uid',
        'role',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden = [
        'deleted_at',
        'seller_account',
        'seller_prices',
        'avatar',
        'uid',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'first_name' => 'string',
        'last_name' => 'string',
        'country' => 'string',
        'uid' => 'string',
        'email' => 'string',
        'phone' => 'string',
        'role' => 'string',
        'multifactor' => 'boolean',
        'active' => 'boolean',
        'avatar' => 'string',
        'avatar_url' => 'string',
        'verified' => 'boolean',
        'account_type' => 'string',
        'stripe_id' => 'string',
        'seller_account' => 'array',
        'seller_prices' => 'array',
        'pm_type' => 'string',
        'pm_last_four' => 'string',
        'trial_ends_at' => 'string',
        'send_in_blue_contact_id' => 'integer',
    ];

    public function fullName(): Attribute
    {
        return Attribute::make(
            get: fn ($value, $attributes) => $attributes['first_name'] . ' ' . $attributes['last_name']
        );
    }

    /**
     * Get the applications of the user.
     */
    public function applications()
    {
        return $this->hasMany(UserApplication::class);
    }

    /**
     * Get the applications of the user.
     */
    public function producer_info()
    {
        return $this->hasOne(ProducerApplication::class);
    }

    /**
     * Get the scripts of the user.
     */
    public function scripts()
    {
        return $this->hasMany(Script::class);
    }

    public function scriptOrders()
    {
        return $this->hasMany(ScriptOrder::class);
    }

    public function esignatures()
    {
        return $this->hasMany(SignatureRequest::class, 'user_id', 'id');
    }

    public function verify()
    {
        $this->verified = true;
    }
    public static function getUserEmail(string $id): string
    {
        return  User::find($id)->email;
    }
    public static function getActiveUsers($search = null)
    {
        $user = User::where([
            ['verified', '=', 1],
            ['active', '=', 1],
            ['account_type', '=', 'writer_in_program']
        ]);
        if ($search) {
            $user = $user->where("name", "%{$search}")
                ->orWhere("email", "%{$search}");
        }
        return $user->paginate(10);
    }

    /**
     * Get all of the subscription for the User
     *
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function subscription()
    {
        return $this->hasOne(Subscription::class);
    }

    public function subscribed()
    {
        $user_subscr = DB::table('subscriptions')->where('user_id','=', Auth::user()->id)->where('stripe_status','=', 'active')->first();
        return empty($user_subscr)? false: true;
    }


    public function getSubscriptionType()
    {
        $user_subscr = DB::table('subscriptions')->where('user_id','=', Auth::user()->id)->where('stripe_status','=', 'active')->first();
        if (empty($user_subscr)) {
            return '';
        }
        return $user_subscr->name;
    }
}
