<?php

namespace App\Models;

use App\Models\Concerns\Uuids;
use App\Notifications\ScheduleOnceInvite;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Carbon;

class UserApplication extends Model
{
    use HasFactory, SoftDeletes;

    const TYPE_PRODUCER = 'producer_application';
    const TYPE_WRITER = 'writer_application';
    const TYPE_CW = 'commissioned_work';

    protected $fillable = [
        'user_id',
        'applicationable_id',
        'applicationable_type'
    ];

    protected $hidden = ['deleted_at'];

    protected $casts = [
        'applicationable_id' => 'integer',
        'applicationable_type' => 'string',
        'user_id' => 'integer',
        'approved_at' => 'datetime',
        'rejected_at' => 'datetime',
    ];

    /**
     * Get the application.
     */
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    /**
     * Get the parent applicationable model (producer or writer).
     */
    public function applicationable()
    {
        return $this->morphTo(__FUNCTION__, 'applicationable_type', 'applicationable_id');
    }

    public function approve()
    {
        $this->approved_at = Carbon::now();
    }

    public function reject()
    {
        $this->rejected_at = Carbon::now();
    }

    public function meet(TeamMember $teamMember)
    {
        $this->user->notify(new ScheduleOnceInvite(
            $this,
            $teamMember
        ));
    }
}
