<?php

namespace App\Providers;

use App\Events\EsignatureContract;
use App\Events\TeamInviteEmail;
use App\Events\UploadFiles;
use App\Events\UserRegistered;
use App\Listeners\FileUploaded;
use App\Listeners\SendEsignatureContract;
use App\Listeners\SendTeamInviteEmail;
use App\Listeners\SendWelcomeEmail;
use Illuminate\Auth\Events\Registered;
use Illuminate\Auth\Listeners\SendEmailVerificationNotification;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;
use Illuminate\Support\Facades\Event;

class EventServiceProvider extends ServiceProvider
{
    /**
     * The event listener mappings for the application.
     *
     * @var array<class-string, array<int, class-string>>
     */
    protected $listen = [
        Registered::class => [
            SendEmailVerificationNotification::class,
        ],
        UserRegistered::class => [
            SendWelcomeEmail::class,
        ],
        TeamInviteEmail::class => [
            SendTeamInviteEmail::class,
        ],
        UploadFiles::class => [
            FileUploaded::class,
        ],
        EsignatureContract::class => [
            SendEsignatureContract::class,
        ]
    ];

    /**
     * Register any events for your application.
     *
     * @return void
     */
    public function boot()
    {
        //
    }
}
