<?php

namespace App\Services\Dwolla\FundingSources;

class FundingSource extends FundingSourceApi
{
    public static function createFundingSource($id, $routingNumber, $accountNumber, $bankAccountType, $name)
    {
        $fsApi = self::initializeFundingSourceApi();

        $dwolla_api_env_url = config('services.dwolla.env_url');
        $funding_url = $dwolla_api_env_url . '/' . $id . '';

        $new_fs = $fsApi->createCustomerFundingSource(
            array(
                'routingNumber' => $routingNumber,
                'accountNumber' => $accountNumber,
                'bankAccountType' => $bankAccountType,
                'name' => $name,
            ),
            $funding_url
        );

        return $new_fs;
    }

    public static function listFundingSource($id)
    {
        $fsApi = self::initializeFundingSourceApi();

        $dwolla_api_env_url = config('services.dwolla.env_url');
        $customer_url = $dwolla_api_env_url . '/customers/' . $id . '';

        $fundingSources = $fsApi->getCustomerFundingSources($customer_url);
        return $fundingSources;
    }

    public static function balanceFundingSource($id)
    {
        $fsApi = self::initializeFundingSourceApi();

        $dwolla_api_env_url = config('services.dwolla.env_url');
        $customer_url = $dwolla_api_env_url . '/customers/' . $id . '';

        $fundingSourcesResponse = $fsApi->getCustomerFundingSources($customer_url);
        $fundingSources = $fundingSourcesResponse->_embedded->{'funding-sources'};

        foreach ($fundingSources as $fundingsource) {
            if ($fundingsource->type == 'balance') {
                return [$fsApi, $fundingsource];
            }
        }
    }

    public static function bankFundingSource($id)
    {
        $fsApi = self::initializeFundingSourceApi();

        $dwolla_api_env_url = config('services.dwolla.env_url');
        $customer_url = $dwolla_api_env_url . '/customers/' . $id . '';

        $fundingSourcesResponse = $fsApi->getCustomerFundingSources($customer_url);
        $fundingSources = $fundingSourcesResponse->_embedded->{'funding-sources'};

        foreach ($fundingSources as $fundingsource) {
            if ($fundingsource->type == 'bank') {
                return $fundingsource;
            }
        }
    }

    public static function getBalance($id)
    {
        $balanceFS = self::balanceFundingSource($id);
        $fsApi = $balanceFS[0];
        $balanceFS_Id = $balanceFS[1]->id;

        $dwolla_api_env_url = config('services.dwolla.env_url');
        $fsUrl = $dwolla_api_env_url . '/funding-sources/' . $balanceFS_Id . '';

        $balanceResponse = $fsApi->getBalance($fsUrl);
        $balance = $balanceResponse->balance->value;
        return $balance;
    }

    public static function removeFundingSource($id)
    {
        $fundingSourceUrl = 'https://api-sandbox.dwolla.com/funding-sources/'.$id;
        $fsApi = self::initializeFundingSourceApi();
        $response = $fsApi->softDelete(['removed' => true], $fundingSourceUrl);
        return $response;
    }
}
