<?php

namespace App\Services\Dwolla\Transfer;

use App\Services\Dwolla\FundingSources\FundingSource;
use Illuminate\Support\Str;
use DwollaSwagger;

class TransferApi extends FundingSource
{
    public static function TranferMoney($buyerId, $sellerId, $amount)
    {
        // Initilaze the Funding Source Api
        $buyerfs = self::balanceFundingSource($buyerId);
        $sellerfs = self::balanceFundingSource($sellerId);

        $buyerSourceId = $buyerfs[1]->id;
        $sellerSourceId = $sellerfs[1]->id;

        // Create Funding Url's
        $dwolla_api_env_url = config('services.dwolla.env_url');
        $buyer_url = $dwolla_api_env_url . '/funding-sources/' . $buyerSourceId . '';
        $seller_url = $dwolla_api_env_url . '/funding-sources/' . $sellerSourceId . '';

        $transfer_request = array(
            '_links' =>
            array(
                'source' =>
                array(
                    'href' => $buyer_url,
                ),
                'destination' =>
                array(
                    'href' => $seller_url,
                ),
            ),
            'amount' =>
            array(
                'currency' => 'USD',
                'value' => $amount,
            )
        );

        // Transfer API
        $apiClient = new DwollaSwagger\ApiClient($dwolla_api_env_url);
        $transferApi = new DwollaSwagger\TransfersApi($apiClient);
        $transferUrl = $transferApi->create(
            $transfer_request,
            [
                'Idempotency-Key' => Str::uuid()->toString(),
            ]
        );

        // Message for Success and Faliure
        if ($transferUrl) {
            $transferData = $transferApi->byId($transferUrl);
            // save $transferData->id to database and send email notification;
            return ['transfer_id' => $transferData->id];
        } else {
            return ['status' => false, 'message' => "Bill payment has failed. Please try again."];
        }
    }

    public static function getTransactionDetails($id)
    {
        $dwolla_api_env_url = config('services.dwolla.env_url');
        $customer_url = $dwolla_api_env_url . '/customers/' . $id . '';

        // Client Token Class
        self::generateAchAPIToken();

        $apiClient = new DwollaSwagger\ApiClient($dwolla_api_env_url);
        $TransfersApi = new DwollaSwagger\TransfersApi($apiClient);

        $transfersResponse = $TransfersApi->getCustomerTransfers($customer_url);

        $transfers = $transfersResponse->_embedded->{'transfers'};
        return $transfers;
    }
}
