<?php

namespace App\Services\Esignatures;

use App\Models\SignatureRequest;
use App\Models\User;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Log;


//This is Esignature Class
class SignatureServices
{
    /**
     * @var Client $client
     */
    protected $client;

    /**
     * @param Client $client
     */
    public function __construct()
    {
        $this->client = new Client();
    }

    public function send(SignatureRequest $signatureRequest)
    {
        try {
            $response = $this->client->post($this->getUrl('contracts'), [
                'headers' => [
                    'Accept'     => 'application/json',
                ],
                'json' => [
                    'template_id' => $signatureRequest->template_id,
                    'test' => $signatureRequest->sandbox_mode,
                    'custom_webhook_url' => $signatureRequest->webhook_url,
                    'signers' => [
                        [
                            'name' => $signatureRequest->name,
                            'email' => $signatureRequest->email,
                            'signed_document_delivery_method' => $signatureRequest->delivery_method
                        ],
                        [
                            'name' => config('services.e-signature.company_name'),
                            'email' => config('services.e-signature.company_email'),
                            'signed_document_delivery_method' => $signatureRequest->delivery_method
                        ]
                    ],
                    'placeholder_fields' => [
                        [
                            "api_key" => "Screenwriters Full Name",
                            "value" => $signatureRequest->name
                        ],
                        [
                            "api_key" => "date",
                            "value" => $signatureRequest->updated_at
                        ]
                    ]
                ]
            ]);
            
            if ($response->getStatusCode() == 200) {
                $data = json_decode($response->getBody()->getContents())->data->contract;

                $signer = $data->signers[0];

                $signatureRequest->contract_title = $data->title;
                $signatureRequest->contract_id = $data->id;
                $signatureRequest->signer_id = $signer->id;
                $signatureRequest->link_expiry_date = $signer->link_expiry_date;
                $signatureRequest->sign_page_url = $signer->sign_page_url;
                $signatureRequest->save();
                return $signer->sign_page_url;

            }
        } catch (\Exception $exception) {
            Log::error($exception->getMessage());
        }
    }

    public function getUrl($url)
    {
        return 'https://esignatures.io/api/' . $url . '?token=' . config('services.e-signature.key');
    }

    /**
     * This method returns url of the e-signature api
     *
     * @param $endpoint
     * @return string
     */
    public function makeApiEndpoint($endpoint)
    {
        return "{$endpoint}?token=" . config('services.e-signature.key');
    }
}
