<?php

use App\Models\User;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateUsersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('users', function (Blueprint $table) {

            $table->bigIncrements('id');

            $table->string('first_name');
            $table->string('last_name');
            $table->string('country', 255)->nullable();
            $table->string('uid')->unique()->index();
            $table->string('email')->nullable()->unique();

            $table->enum('role',['superadmin','admin','analyst','producer','screenwriter'])->nullable();

            $table->string('phone')->unique()->nullable();
            $table->text('avatar')->nullable();
            $table->text('avatar_url')->nullable();
            $table->boolean('active')->default(true);
            $table->boolean('verified')->default(false);
            $table->string('account_type')->nullable();
            $table->json('seller_account')->nullable();
            $table->json('seller_prices')->nullable();
            $table->unsignedBigInteger('send_in_blue_contact_id')->nullable();
            $table->softDeletes();

            $table->string('dwolla_customer_id')->nullable()->unique();
            $table->string('dwolla_funding_source_id')->nullable()->unique();
            $table->string('stripe_customer_id')->nullable()->unique();

            $table->timestamps();

            $table->rememberToken();
        });

        // Creating the Super Admin
        User::create([
            'first_name' => 'Super',
            'last_name' => 'Admin',
            'email' => 'woaccelarator@gmail.com',
            'phone' => '+447123123456',
            'uid' => 'superadminuid',
            'role' => 'superadmin',
        ]);
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('users');
    }
}
