<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateScriptsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('scripts', function (Blueprint $table) {
            $table->increments('id');
            $table->string('title');
            $table->text('synopsis');
            $table->text('logline');
            $table->text('tagline');
            $table->enum('pages', ['90-110','111-140','140+']);
            $table->enum('where', ['asia', 'europe', 'north-america', 'south-america', 'africa', 'antarctica', 'australia']);
            $table->enum('genre', ['action','adventure','comedy', 'drama', 'fantasy', 'foreign', 'historical', 'horrow', 'science', 'thriller', 'western', 'other']);
            $table->enum('budget', ['No Budget < 500K (Independent)','Micro Budget 500k > 1m (Independent)','Ultra Low Budget 1m to 5m (Independent)', 'Low Budget 5m to 20m (Independent or Studio)', 'Medium Budget 20m - 100m (Studio Backed)', 'Big Budget 100m+ (Studio Backed)']);
            $table->enum('timeline', ['past','present','future']);
            $table->enum('content_ratings', ['g','pg','pg-13', 'r']);

            $table->text('treatment')->nullable();
            $table->text('script')->nullable();

            $table->dateTime('optioned_until')->nullable();
            $table->dateTime('published_at')->nullable();

            $table->foreignId('user_id')
                ->constrained('users')->cascadeOnDelete();

            $table->nullableMorphs('application');

            $table->softDeletes();

            $table->enum('submissions', [0,1,2])->default(0);

            $table->timestamp('accpeted_at')->nullable();
            $table->timestamp('rejected_at')->nullable();
            $table->timestamp('submitted_at')->nullable();

            $table->dateTime('signature_requested_at')->nullable();
            $table->dateTime('payment_requested_at')->nullable();
            $table->boolean('treatment_status')->default(false);
            $table->enum('publish_status',['draft','submitted','in_review','ready','accepted','denied','purchased','payment_requested','payment_completed'])->nullable();

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('scripts');
    }
}
