<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="{{ asset('/css/app.css') }}" rel="stylesheet">
    <script src="{{ asset('/js/app.js') }}" defer></script>
    <title>Admin Login</title>
    <style>
        body {
            font-family: sans-serif;
            background-color: #fff;
        }

        .Login_body>header>img {
            object-fit: contain;
            padding-left: 4rem;
        }

        .Login_body .container {
            width: 33%;
        }

        .Login_body .container h2 {
            font-weight: 600;
            font-size: 35px;
        }

        .Login_body .container label:not(label[for='admin_rememberme']) {
            font-weight: 600;
        }

        .Login_body .container input:not(input[type='checkbox']) {
            height: 3rem;
            padding-inline: 1.5rem;
        }

        .Login_body .container span {
            color: #2B79BD;
        }

        .Login_body .container button {
            width: 100%;
            background-color: #2B79BD;
            color: #fff;
            border-radius: 10px;
            padding-block: 0.6rem;
            font-size: 18px;
            letter-spacing: 0.1rem;
        }

        /* Small Screens */

        @media screen and (max-width: 1200px) {

            .Login_body .container {
                width: 42%;
            }

        }

        @media screen and (max-width: 992px) {

            .Login_body .container {
                width: 50%;
            }

        }

        @media screen and (max-width: 768px) {

            .Login_body .container {
                width: 100%;
            }

        }

        @media screen and (max-width: 576px) {

            .Login_body>header {
                text-align: center;
            }

            .Login_body>header>img {
                object-fit: contain;
                padding-left: 0;
            }

        }

        /* Loader  */

        .loader-parent {
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            position: fixed;
            width: 100%;
            z-index: 1;
        }

        .loader {
            border: 8px solid #d8cccc;
            border-radius: 50%;
            border-top: 8px solid #2B79BD;
            width: 70px;
            height: 70px;
            -webkit-animation: spin 1s linear infinite;
            animation: spin 1s linear infinite;
        }

        @-webkit-keyframes spin {
            0% {
                -webkit-transform: rotate(0deg);
            }

            100% {
                -webkit-transform: rotate(360deg);
            }
        }

        @keyframes spin {
            0% {
                transform: rotate(0deg);
            }

            100% {
                transform: rotate(360deg);
            }
        }
    </style>
</head>

<body class="Login_body">
    <div class="loader-parent d-none">
        <div class="loader"></div>
    </div>
    <header>
        <img src="{{ asset('/img/wo accelerator Logo.jpg') }}" width="300px" height="100px" alt="" class="img-fluid">
    </header>
    <div class="container mt-0">
        <div class="row mx-0 w-100">
            <h2 class="text-center mb-5">Login</h2>
            <div class="bg-danger p-4 rounded-lg mb-3 text-light text-center d-none auth_failed"></div>
            <form action="{{ route('superadmin.login') }}" method="post" id="login">
                @csrf
                <div class="mb-3">
                    <label for="email" class="form-label">Email Address</label>
                    <input type="email" class="form-control" name="email" id="email" placeholder="Enter your Email Address">
                    <div class="text-danger mt-2 fs-6 email_error">@error('email') {{$message}} @enderror</div>
                </div>
                <div class="mb-3">
                    <label for="password" class="form-label">Password</label>
                    <input type="password" class="form-control" name="password" id="password" placeholder="Enter your Password" autocomplete="on">
                    <div class="text-danger mt-2 fs-6 password_error">@error('password') {{$message}} @enderror</div>
                </div>
                <div class="mb-5 text-sm-start text-center">
                    <label class="form-check-label mb-sm-0 mb-3" for="remember_me">
                        <input type="checkbox" class="form-check-input me-1" name="remember_me" id="remember_me">
                        Remember me
                    </label>
                </div>
                <div class="mb-5 text-center">
                    <button type="submit" class="border-0">Login</button>
                </div>
            </form>
        </div>
    </div>

    @if(@session('Invalid') == 'success')
    <script>
        var errorField = document.getElementsByClassName('auth_failed')[0];
        errorField.classList.remove('d-none');
        errorField.innerText = 'Invalid Email or Password';
    </script>

    @endif

    <script>
        window.onload = function() {

            // Form Fields Validation on Keyup Event
            $('form input').not('input[type="checkbox"]').on('keyup', (e) => {
                const targetField = $(e.currentTarget);

                // For Adjusting message according to Field
                const targetFieldName = targetField.attr('name');
                var requireMessage = '';
                switch (targetFieldName) {
                    case 'email':
                        requireMessage = 'The Email Address is Required Field';
                        break;
                    case 'password':
                        requireMessage = 'The Password is Required Field';
                        break;
                }

                var fieldValue = targetField.val();
                const errorField = targetField.next('div.text-danger');

                // Required Message
                if (fieldValue == '') {
                    errorField.text(requireMessage);
                    targetField.addClass('border border-danger');
                } else {
                    errorField.text('');
                    targetField.removeClass('border border-danger');
                }

                // Valid Email Message - Note that the below regex does work despite any linting errors you receieve.
                // You can alsways use regexlib.com or regex101.com for testing.
                if (targetFieldName == 'email') {
                    if (errorField.text() == '') {
                        let result = fieldValue.match(/^([a-zA-Z0-9_\-\.\+]+)@([a-zA-Z0-9_\-\.]+)\.([a-zA-Z]{2,5})$/);
                        if (!result) {
                            errorField.text('Enter a Valid Email Address');
                            targetField.addClass('border border-danger');
                        }
                    }
                }
            });

            // Function to check the form validation during submission
            function submittionTimeValidation(form) {
                var results = true;
                var generalResults = true;

                // Form Values
                const formValues = ['email', 'password'];

                // Loop to check the fields
                formValues.forEach(elem => {
                    if (form.get(elem) == '') {
                        results = false;
                    }
                });

                var allErrorFields = $('.text-danger');
                for (let i = 0; i < allErrorFields.length; i++) {
                    if (allErrorFields[i].innerText != '') {
                        generalResults = false;
                    }
                }

                if (results == false || generalResults == false) {
                    return false;
                } else {
                    return true;
                }

            }

            //Page Refresh (Need to Look)
            $('.change_url').on('click', (e) => {
                location.href = (new URL(location.href)).origin + '/wocontrolpanel20/';
            });

            //USER SIGNIN
            $('#login').on('submit', (e) => {
                $('.loader-parent').removeClass('d-none');
                e.preventDefault();

                var form = new FormData(e.currentTarget);

                // Form Validation during Submission
                const result = submittionTimeValidation(form);

                if (result) {
                    $('#login').off('submit');
                    $('#login').trigger('submit');
                } else {

                    var allErrorFields = $('.text-danger');
                    var ifTextAvailable = false;
                    $('.loader-parent').addClass('d-none');
                    for (let i = 0; i < allErrorFields.length; i++) {
                        if (allErrorFields[i].innerText != '') {
                            $('.auth_failed').addClass('d-none');
                            $('.auth_failed').text('');
                            $('html, body').animate({
                                scrollTop: $('.text-danger:eq(' + i + ')').offset().top - 100
                            }, 400);
                            ifTextAvailable = true;
                            break;
                        }
                    }

                    if (!ifTextAvailable) {
                        $('.auth_failed').removeClass('d-none');
                        $('.auth_failed').text('Enter your Full Details');
                        $('html, body').animate({
                            scrollTop: $('.auth_failed').offset().top - 10
                        }, 400);
                    }

                }

            });
        }
    </script>

</body>

</html>