<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="csrf-token" content="{{ csrf_token() }}" />
    <title>WoAccelerator Analyst Dashboard</title>
    <link rel="stylesheet" href="{{ asset('/css/app.css') }}">
    <script src="{{ asset('/js/app.js') }}" defer></script>
    <script src="{{ asset('/js/common.js') }}" defer></script>
    <script src="{{ asset('/js/analyst.js') }}" defer></script>

</head>

<body class="analyst_body">

    <!-- SideBar -->

    <nav class="pt-3 analyst shadow">
        <a href="{{ route('analyst.scriptsqueue') }}" class="text-decoration-none">
            <span class="Logo_First">Wo</span>
            <span class="Logo_Second"> Accelerator</span>
        </a>
        <span class="cancel_menu ms-3"><i class="fa-solid fa-xmark"></i></span>
        <ul class="mt-5 ps-0 menu_items">
            <li
                class="{{ request()->is('analyst/scriptsqueue', 'analyst/scriptsreview', 'analyst/scriptssent', 'analyst/script') ? 'active' : '' }}">
                <a href="{{ route('analyst.scriptsqueue') }}" class="text-decoration-none">
                    <span><i class="fa-solid fa-scroll"></i></span>
                    <span>Scripts</span>
                </a>
            </li>
            <li class="{{ request()->is('analyst/settings', 'analyst/settings/*') ? 'active' : '' }}">
                <a href="{{ route('analyst.settings') }}" class="text-decoration-none">
                    <span><i class="fa-solid fa-gear"></i></span>
                    <span>Settings</span>
                </a>
            </li>
            <li>
                <form action="{{ route('logout') }}" method="post" class="inline">
                    @csrf
                    <button type="submit" class="border-0 bg-transparent">
                        <span><i class="fa-solid fa-arrow-right-from-bracket"></i></span>
                        <span>Logout</span>
                    </button>
                </form>
            </li>
        </ul>
    </nav>

    <!-- Top Menu -->

    <section id="analyst_top_menu">
        <span class="menu_button"><i class="fa-solid fa-bars"></i></span>
        <div class="app-utility-item app-notifications-dropdown dropdown">
            <a class="dropdown-toggle no-toggle-arrow" id="notifications-dropdown-toggle" data-bs-toggle="dropdown"
                href="#" role="button" aria-expanded="false" title="Notifications">
                <svg width="1em" height="1em" viewBox="0 0 16 16" class="bi bi-bell icon" fill="currentColor"
                    xmlns="http://www.w3.org/2000/svg">
                    <path d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2z" />
                    <path fill-rule="evenodd"
                        d="M8 1.918l-.797.161A4.002 4.002 0 0 0 4 6c0 .628-.134 2.197-.459 3.742-.16.767-.376 1.566-.663 2.258h10.244c-.287-.692-.502-1.49-.663-2.258C12.134 8.197 12 6.628 12 6a4.002 4.002 0 0 0-3.203-3.92L8 1.917zM14.22 12c.223.447.481.801.78 1H1c.299-.199.557-.553.78-1C2.68 10.2 3 6.88 3 6c0-2.42 1.72-4.44 4.005-4.901a1 1 0 1 1 1.99 0A5.002 5.002 0 0 1 13 6c0 .88.32 4.2 1.22 6z" />
                </svg>
                <span class="icon-badge">{{ Auth::user()->unreadNotifications->count() }}</span>
            </a>
            <!--//dropdown-toggle-->

            <div class="dropdown-menu p-0" aria-labelledby="notifications-dropdown-toggle">
                <div class="dropdown-menu-header p-3">
                    <h5 class="dropdown-menu-title mb-0">Notifications</h5>
                </div>
                <!--//dropdown-menu-title-->
                <div class="dropdown-menu-content">
                    <div class="item p-3">
                        @foreach (Auth::user()->unreadNotifications as $notification)
                            <div class="row gx-2 justify-content-between align-items-center">
                                <div class="col-auto">
                                    <img class="profile-image" src="https://picsum.photos/40/40" alt="">
                                </div>
                                <!--//col-->
                                <div class="col">
                                    <div class="info">
                                        <div class="desc"> <h6>
                                            {{ $notification->data['title'] }}
                                            </h6>
                                        <p>{{ $notification->data['body'] }}
                                            </p> </div>
                                        <div class="meta"> {{ \Carbon\Carbon::createFromFormat('Y-m-d H:i:s', $notification->created_at)->diffForHumans()}}</div>
                                    </div>
                                </div>
                                <!--//col-->
                            </div>
                        @endforeach

                        <!--//row-->
                        <a class="link-mask" href="notifications.html"></a>
                    </div>
                </div>
                <!--//dropdown-menu-content-->

                <div class="dropdown-menu-footer p-2 text-center">
                    <a href="notifications.html">View all</a>
                </div>

            </div>
            <!--//dropdown-menu-->
        </div>
        <span><img src="https://picsum.photos/40/40" alt="Profile Picture" class="image-fluid"></span>
    </section>

    @yield('content')

    <!-- This script is a one time use case based on the following condition:
        1. The calulcate ratings function exist only on a single page.
        2. Therefore it makese sense to only load it on that individual page.
        3. Then, we should call this analyst script here as part of the layout and place it in the global JS
    -->

    @stack('js')


    <script defer src="https://cdn.jsdelivr.net/npm/@flasher/flasher@1.1.0/dist/flasher.min.js"></script>
    <script>
        flasher.addTheme('bootstrap', {
            styles: 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css', // optional
            render(envelope) {
                const notification = envelope.notification;
                const map = {
                    success: 'alert-success',
                    info: 'alert-info',
                    warning: 'alert-warning',
                    error: 'alert-danger',
                };

                return `
                <div class="alert ${map[notification.type]}">
                  ${notification.message}
                </div>
            `;
            },
        })
    </script>
</body>

</html>
